matrix_test_list: Create list of matrices most used in the tests

Description Usage

View source: R/utlity_functions.R

Description

Create list of matrices most used in the tests

Usage

1

jorgenfrost/compost documentation built on Nov. 4, 2019, 3:10 p.m.